@@ -1,7 +1,7 @@
 """Install packages with pip."""
-import os
+# import os
 import subprocess
-import shutil
+# import shutil
 import shlex
 
 
@@ -18,23 +18,25 @@ def pip(pkg, project_path, pname):
         Packages installed or not installed
     '''
     if pkg:
-        pip_path = shutil.which('pip3')
-        shell_path = os.environ['SHELL']
-        shell = os.path.basename(shell_path)
-        if shell == 'bash' or 'zsh':
-            cmd = ['source', f'{pname}/bin/activate']
-        elif shell == 'csh' or 'tcsh':
-            cmd = ['source', f'{pname}/bin/activate.csh']
-        elif shell == 'fish':
-            cmd = ['.', f'{pname}/bin/activate.fish']
+        pip_path = f"{pname}/bin/pip3"
+        # shell_path = os.environ['SHELL']
+        # shell = os.path.basename(shell_path)
+        # if shell == "bash" or "zsh":
+        #     cmd = f"{pname}/bin/activate"
+        # elif shell == "csh" or "tcsh":
+        #     cmd = f"{pname}/bin/activate.csh"
+        # elif shell == "fish":
+        #     cmd = f"{pname}/bin/activate.fish"
+        # else:
+        #     raise OSError("\nUnknown Shell!")
         pkg = input("\n📦 Packages you want to install: ")
         pkgs = shlex.split(pkg)
-        args = [pip_path, 'install']
+        args = [pip_path, "install"]
         for i in range(len(args)):
             pkgs.insert(i, args[i])
 
-        subprocess.run(cmd, shell=True, executable=shell_path)
-        os.chdir(project_path)
+        # subprocess.run(["source", cmd], shell=True, executable=shell_path)
+        # os.chdir(project_path)
         print('\n🔰 Downloading packages...\n')
         subprocess.run(pkgs, check=True)
         return 1
